package WebGUI::i18n::German::Asset_Calendar;
use utf8;
our $I18N = {
  'Add' => {
    'lastUpdated' => '1234738123',
    'message' => 'Hinzufügen'
  },
  'Add a feed' => {
    'lastUpdated' => '1234738166',
    'message' => 'iCal-feed hinzufügen'
  },
  'DN' => {
    'lastUpdated' => '1234738176',
    'message' => 'NW'
  },
  'Feed URL' => {
    'lastUpdated' => '1234738186',
    'message' => 'Feed URL'
  },
  'New Day' => {
    'lastUpdated' => '1229991991',
    'message' => 'Neuer Tag'
  },
  'New Month' => {
    'lastUpdated' => '1229991999',
    'message' => 'Neuer Monat'
  },
  'New Year' => {
    'lastUpdated' => '1229992006',
    'message' => 'Neues Jahr'
  },
  'UP' => {
    'lastUpdated' => '1234738106',
    'message' => 'VW'
  },
  'add event' => {
    'lastUpdated' => '1192786210',
    'message' => 'Ereignis eintragen'
  },
  'admin' => {
    'lastUpdated' => '1178788317',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer sich im Admin Modus befindet.'
  },
  'adminControls' => {
    'lastUpdated' => '1178788397',
    'message' => 'Dies sind die Icons und URLs, die das Bearbeiten, Ausschneiden, Kopieren, Löschen und Umstrukturierung von Assets erlauben.'
  },
  'asset not committed' => {
    'lastUpdated' => '1224833738',
    'message' => '<h1>Fehler!</h1><p>Sie müssen den Kalender committen bevor Sie einen neuen Termin anlegen können.&nbsp;</p>'
  },
  'assetName' => {
    'lastUpdated' => '1170409428',
    'message' => 'Kalender'
  },
  'current' => {
    'lastUpdated' => '1206392563',
    'message' => 'Aktuell'
  },
  'dayAbbr' => {
    'lastUpdated' => '1178788428',
    'message' => 'Die Abkürzung f&uuml;r den Namen des aktuellen Tages.'
  },
  'dayCurrent' => {
    'lastUpdated' => '1269421117',
    'message' => 'Ein boolscher Wert der wahr ist, wenn dies der heutige Tag ist'
  },
  'dayName' => {
    'lastUpdated' => '1178788438',
    'message' => 'Der Name des aktuellen Tages.'
  },
  'dayNames' => {
    'lastUpdated' => '1269421165',
    'message' => 'Eine Schleife, die die Namen und Abkürzungen der Wochentage liefert.'
  },
  'dayOfMonth' => {
    'lastUpdated' => '1178788496',
    'message' => 'Welcher Tag des Monats ist dieser Tag; Zahl zwischen 1...31.'
  },
  'dayOfWeek' => {
    'lastUpdated' => '1178788483',
    'message' => 'Welcher Tag der Woche ist dieser Tag; Zahl zwischen 1...7.'
  },
  'dayUrl' => {
    'lastUpdated' => '1269421204',
    'message' => 'Eine URL, die alle Einträge für diesen Tag anzeigt.'
  },
  'days' => {
    'lastUpdated' => '1178788585',
    'message' => 'Diese Schleife enthält alle Termine und Label für die Tage an denen Sie auftreten. Alle Tage der Woche sind in der Schleife enthalten, egal ob sie Termine enthalten oder nicht.'
  },
  'defaultDate description' => {
    'lastUpdated' => '1264460703',
    'message' => 'Das Standarddatum, das dem Benutzer angezeigt wird.'
  },
  'defaultDate label' => {
    'lastUpdated' => '1264460712',
    'message' => 'Standarddatum'
  },
  'defaultDate value current' => {
    'lastUpdated' => '1178788627',
    'message' => 'Das aktuelle Datum'
  },
  'defaultDate value first' => {
    'lastUpdated' => '1178788640',
    'message' => 'Der erste Termin im Kalender'
  },
  'defaultDate value last' => {
    'lastUpdated' => '1178788656',
    'message' => 'Der letzte Termin im Kalender'
  },
  'defaultView description' => {
    'lastUpdated' => '1178788674',
    'message' => 'Die Standard Ansicht, die dem Benutzer angezeigt wird.'
  },
  'defaultView label' => {
    'lastUpdated' => '1178788682',
    'message' => 'Standard Ansicht'
  },
  'defaultView value day' => {
    'lastUpdated' => '1178788691',
    'message' => 'Tag'
  },
  'defaultView value list' => {
    'lastUpdated' => '1204544515',
    'message' => 'Liste'
  },
  'defaultView value month' => {
    'lastUpdated' => '1178788696',
    'message' => 'Monat'
  },
  'defaultView value week' => {
    'lastUpdated' => '1178788701',
    'message' => 'Woche'
  },
  'dmy' => {
    'lastUpdated' => '1178789252',
    'message' => 'Dieser Tag im dd-mm-yyyy Format. yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  },
  'editForm icalInterval description' => {
    'lastUpdated' => '1224834602',
    'message' => 'Zeitraum, der im iCal Feed dargestellt wird.'
  },
  'editForm icalInterval label' => {
    'lastUpdated' => '1224834688',
    'message' => 'ICal Feed Intervall'
  },
  'editForm listViewPageInterval description' => {
    'lastUpdated' => '1224834719',
    'message' => 'Zeitraum, der in einer einzelnen Seite in der Listenansicht dargestellt wird'
  },
  'editForm listViewPageInterval label' => {
    'lastUpdated' => '1225306990',
    'message' => 'Interval Listenansicht'
  },
  'editForm templateIdList description' => {
    'lastUpdated' => '1224834760',
    'message' => 'Dieses Template zeigt den Kalender in der Listenansicht an.'
  },
  'editForm templateIdList label' => {
    'lastUpdated' => '1224834772',
    'message' => 'Listenansicht Template'
  },
  'editForm templateIdPrintList description' => {
    'lastUpdated' => '1224834809',
    'message' => 'Dieses Template druckt den Kalender in Listenansicht.'
  },
  'editForm templateIdPrintList label' => {
    'lastUpdated' => '1224834824',
    'message' => 'Listenansicht Druck Template'
  },
  'editForm workflowIdCommit description' => {
    'lastUpdated' => '1224834879',
    'message' => 'Wählen Sie einen Workflow, der benutzt werden soll, um bearbeitete oder neu erstellte Termine committen soll.'
  },
  'editForm workflowIdCommit label' => {
    'lastUpdated' => '1224834893',
    'message' => 'Commit Workflow für Termine'
  },
  'editor' => {
    'lastUpdated' => '1178789288',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer in einer Gruppe ist, die Termine im Kalender bearbeiten darf.'
  },
  'end date' => {
    'lastUpdated' => '1217146809',
    'message' => 'Enddatum'
  },
  'endDayAbbr' => {
    'lastUpdated' => '1178789328',
    'message' => 'Die Abkürzung f&uuml;r den Name des Tages mit dem diese Woche endet.'
  },
  'endDayName' => {
    'lastUpdated' => '1178789342',
    'message' => 'Der Name des Tages mit dem diese Woche endet.'
  },
  'endDayOfMonth' => {
    'lastUpdated' => '1178789371',
    'message' => 'Der Tag des Monats mit dem diese Woche endet; eine Zahl zwischen 1 und 31.'
  },
  'endMonth' => {
    'lastUpdated' => '1178789403',
    'message' => 'Die Nummer (1-12) des Monats in dem diese Woche endet.'
  },
  'endMonthAbbr' => {
    'lastUpdated' => '1178789428',
    'message' => 'Die Abkürzung des Names des Monats in dem diese Woche endet.'
  },
  'endMonthName' => {
    'lastUpdated' => '1178789440',
    'message' => 'Der Name des Monat in dem diese Woche endet.'
  },
  'endYear' => {
    'lastUpdated' => '1178789455',
    'message' => 'Das Jahr in dem diese Woche endet.'
  },
  'epoch' => {
    'lastUpdated' => '1178789493',
    'message' => 'Das Format des Datums dieses Tages im Epochen Format.'
  },
  'events dayVar' => {
    'lastUpdated' => '1178789513',
    'message' => 'Eine Schleife, die alle Termine dieser Stunden enthält.'
  },
  'events weekVar' => {
    'lastUpdated' => '1178789532',
    'message' => 'Eine Schleife, die alle Termine dieses Tages enthält.'
  },
  'extrasUrl' => {
    'lastUpdated' => '1178789551',
    'message' => 'Die URL zum "extras" Verzeichnis von WebGUI.'
  },
  'feeds' => {
    'lastUpdated' => '1178789557',
    'message' => 'Feeds'
  },
  'groupIdEventEdit description' => {
    'lastUpdated' => '1178789586',
    'message' => 'Mitglieder dieser Gruppe können Termine zu diesem Kalender hinzufügen.'
  },
  'groupIdEventEdit label' => {
    'lastUpdated' => '1178789613',
    'message' => 'Wer darf Termine hinzufügen?'
  },
  'help calendar dateTime body' => {
    'lastUpdated' => '1268820888',
    'message' => '<p>Diese Variablen sind für die meisten Datums- und Zeitenangaben im Kalender verf&uuml;gbar.</p><p>HINWEIS: Manchmal haben diese Variablen einen Präfix wie &quot;start&quot; oder &quot;end&quot;. In diesem Fall ist der erste Buchstabe der unten aufgef&uuml;hrten Variablen groß zu schreiben. Die Variable &quot;monthName&quot; zum Beispiel wird dadurch zu &quot;startMonthName&quot;.</p>'
  },
  'help calendar dateTime title' => {
    'lastUpdated' => '1224833935',
    'message' => 'Kalender Datum/Zeit Variablen'
  },
  'help event variables body' => {
    'lastUpdated' => '1224834042',
    'message' => '<p>Falls der Kalender einen Termin darstellt, bekommt er den vollständigen Satz der Termin Variablen und &auml;ndert seinen Namen geringfügig. </p><p>Die Termin Vorlagen Variable &quot;title&quot; wird zu &quot;eventTitle&quot;. Die Termin Schablonen Variable &quot;startDate&quot; wird zu &quot;eventStartDate&quot; und so weiter.</p>'
  },
  'help event variables title' => {
    'lastUpdated' => '1224834056',
    'message' => 'Kalender Termin Variablen'
  },
  'help view list body' => {
    'lastUpdated' => '1224834078',
    'message' => 'Diese Variablen sind in der Kalender Listenansicht verfügbar.'
  },
  'help view list title' => {
    'lastUpdated' => '1224834088',
    'message' => 'Kalender Listenansicht'
  },
  'helpvar dateTime dayAbbr' => {
    'lastUpdated' => '1217147994',
    'message' => 'Der abgekürzte Tag (z.B. &quot;Mo&quot;)'
  },
  'helpvar dateTime dayName' => {
    'lastUpdated' => '1217148011',
    'message' => 'Der Tag (z.B. &quot;Montag&quot;)'
  },
  'helpvar dateTime dayOfMonth' => {
    'lastUpdated' => '1217148043',
    'message' => 'Der Tag im Moment'
  },
  'helpvar dateTime dayOfWeek' => {
    'lastUpdated' => '1217148067',
    'message' => 'Der Tag in der Woche (1 entspricht Montag, 7 entspricht Sonntag)'
  },
  'helpvar dateTime dmy' => {
    'lastUpdated' => '1217148099',
    'message' => 'Der Tag, Monat und das Jahr im britischen Format: TT/MM/JJJJ'
  },
  'helpvar dateTime end' => {
    'lastUpdated' => '1224834431',
    'message' => 'Ein Satz von Datum/Zeit Variablen mit dem Präfix &quot;end&quot;. Siehe auch &quot;Kalender Datum/Zeit Variablen&quot; für weitere Informationen.'
  },
  'helpvar dateTime epoch' => {
    'lastUpdated' => '1217147941',
    'message' => 'Das Datum als Epoche (Anzahl Sekunden seit 1970-01-01 00:00:00). Die Epoche ist für die Verwenung im &bdquo;Date&rdquo;-Makro gedacht.'
  },
  'helpvar dateTime mdy' => {
    'lastUpdated' => '1217147802',
    'message' => 'Der Monat, das Jahr und der Tag im US-Format: MM/TT/JJJJ'
  },
  'helpvar dateTime meridiem' => {
    'lastUpdated' => '1217147777',
    'message' => 'Der Meridiem (A.M. oder P.M.)'
  },
  'helpvar dateTime minute' => {
    'lastUpdated' => '1217147645',
    'message' => 'Die Minuten'
  },
  'helpvar dateTime month' => {
    'lastUpdated' => '1204544539',
    'message' => 'Der Monat (01)'
  },
  'helpvar dateTime monthAbbr' => {
    'lastUpdated' => '1217147634',
    'message' => 'Der abgekürzte Monatsname (z.B. &quot;Jan&quot;)'
  },
  'helpvar dateTime monthName' => {
    'lastUpdated' => '1217147663',
    'message' => 'Der Monatsname (z.B. &quot;Januar&quot;)'
  },
  'helpvar dateTime second' => {
    'lastUpdated' => '1217147264',
    'message' => 'Die Sekunden'
  },
  'helpvar dateTime start' => {
    'lastUpdated' => '1227565743',
    'message' => 'Ein Satz von Datum/Zeit Variablen mit dem Präfix &quot;start&quot;. Siehe &quot;Kalender Datum/Zeit Variablen&quot; für weitere Informationen.'
  },
  'helpvar dateTime year' => {
    'lastUpdated' => '1217147584',
    'message' => 'Das Jahr'
  },
  'helpvar dateTime ymd' => {
    'lastUpdated' => '1217147573',
    'message' => 'Das Jahr, der Monat und Tag im ISO-Format: JJJJ-MM-TT'
  },
  'helpvar newDay' => {
    'lastUpdated' => '1217147353',
    'message' => 'Diese Variable is wahr, wenn das aktuelle Ereignis an einem anderen Tag statt findet als das vorherige.'
  },
  'helpvar newMonth' => {
    'lastUpdated' => '1217147488',
    'message' => 'Diese Variable ist wahr, wenn das aktuelle Ereignis in einem anderen Monat statt findet als das vorherige.'
  },
  'helpvar newYear' => {
    'lastUpdated' => '1217147526',
    'message' => 'Diese Variable ist wahr, wenn das aktuelle Ereignis in einem anderen Jahr statt findet als das vorherige.'
  },
  'helpvar url_nextPage' => {
    'lastUpdated' => '1217147416',
    'message' => 'Der URL der nächsten Seite. Diese Variable existiert nicht, wenn es keine n&auml;chste Seite gibt.'
  },
  'helpvar url_previousPage' => {
    'lastUpdated' => '1217147391',
    'message' => 'Der URL der vorherigen Seite. Diese Variable existiert nicht, wenn es keine vorherige Seite gibt.'
  },
  'hour12' => {
    'lastUpdated' => '1178789697',
    'message' => 'Die Stunde im 12 Stunden Format. 2:00 am Nachmittag wird zu 2:00.'
  },
  'hour24' => {
    'lastUpdated' => '1178789722',
    'message' => 'Die Stunde im 24 Stunden Format. 2:00 am Nachmittag wird zu 14:00.'
  },
  'hourM' => {
    'lastUpdated' => '1178789763',
    'message' => 'Abhängig davon, ob die Stunde vormittags oder nachmittags stattfindet, entweder "am" oder "pm".'
  },
  'hours' => {
    'lastUpdated' => '1178789826',
    'message' => 'Diese Schleife enthält alle Termine und Label für die Stunde in der sie auftreten. Stunden, die keine Termine enthalten, werden in die Schleife nicht mit aufgenommen.'
  },
  'iCal' => {
    'lastUpdated' => '1192798304',
    'message' => 'iCal'
  },
  'keyword' => {
    'lastUpdated' => '1217146372',
    'message' => 'Stichwort'
  },
  'label day' => {
    'lastUpdated' => '1217146228',
    'message' => 'Tag'
  },
  'label month' => {
    'lastUpdated' => '1217146257',
    'message' => 'Monat'
  },
  'label search' => {
    'lastUpdated' => '1217146420',
    'message' => 'Suche'
  },
  'label week' => {
    'lastUpdated' => '1217146268',
    'message' => 'Woche'
  },
  'locale' => {
    'lastUpdated' => '1178789842',
    'message' => 'de_DE'
  },
  'mdy' => {
    'lastUpdated' => '1178789881',
    'message' => 'Das Datum dieses Tages im mm-dd-yyyy Format. yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  },
  'monthAbbr' => {
    'lastUpdated' => '1178789903',
    'message' => 'Die Abkürzung f&uuml;r den Namen dieses Monats'
  },
  'monthCurrent' => {
    'lastUpdated' => '1269421258',
    'message' => 'Ein boolscher Wert der wahr ist, wenn der Kalender den aktuellen Monat anzeigt.'
  },
  'monthEpoch' => {
    'lastUpdated' => '1269421315',
    'message' => 'Datum für diesen Monat in Epoch-Notation.'
  },
  'monthName' => {
    'lastUpdated' => '1178789912',
    'message' => 'Der Name dieses Monats.'
  },
  'monthUrl' => {
    'lastUpdated' => '1269421347',
    'message' => 'URL, um in die Monatsansicht für den aktuellen Kalender zu wechseln.'
  },
  'months' => {
    'lastUpdated' => '1269421407',
    'message' => 'Eine Schleife, die Namen und URLs für die Navigation innerhalb der Monate eines Jahres liefert.'
  },
  'next day' => {
    'lastUpdated' => '1217146242',
    'message' => 'Nächster Tag'
  },
  'next page' => {
    'lastUpdated' => '1217146276',
    'message' => 'Nächste Seite'
  },
  'next week' => {
    'lastUpdated' => '1217146300',
    'message' => 'Nächste Woche'
  },
  'page x of x' => {
    'lastUpdated' => '1217146392',
    'message' => 'Seite %s von %s'
  },
  'pageNextStart' => {
    'lastUpdated' => '1178789956',
    'message' => 'Das Datum des nächsten Tages im Kalender im YYYY-MM-DD (Jahr,Monat,Tag) Format.'
  },
  'pageNextUrl dayVar' => {
    'lastUpdated' => '1178789982',
    'message' => 'URL zum nächsten Tag im Kalender.'
  },
  'pageNextUrl monthVar' => {
    'lastUpdated' => '1309238131',
    'message' => 'URL zum Folgejahr im Kalender.'
  },
  'pageNextUrl weekVar' => {
    'lastUpdated' => '1178790006',
    'message' => 'URL zur nächsten Woche im Kalender.'
  },
  'pageNextYear' => {
    'lastUpdated' => '1269421447',
    'message' => 'Das Jahr das auf das aktuelle Jahr im Kalender folgt.'
  },
  'pagePrevStart' => {
    'lastUpdated' => '1178790041',
    'message' => 'Das Datum des vorhergehenden Tages im Kalender im YYYY-MM-DD (Jahr,Monat,Tag) Format.'
  },
  'pagePrevUrl dayVar' => {
    'lastUpdated' => '1178790058',
    'message' => 'URL zum vorhergehenden Tag im Kalender.'
  },
  'pagePrevUrl monthVar' => {
    'lastUpdated' => '1309238169',
    'message' => 'URL zum Vorjahr im Kalender.'
  },
  'pagePrevUrl weekVar' => {
    'lastUpdated' => '1178790073',
    'message' => 'URL zur vorhergehenden Woche im Kalender.'
  },
  'pagePrevYear' => {
    'lastUpdated' => '1269421501',
    'message' => 'Das Jahr das dem aktuellen Jahr im Kalender vorangeht'
  },
  'paramStart' => {
    'lastUpdated' => '1178790089',
    'message' => 'Das Start Datum des Kalenders.'
  },
  'paramType' => {
    'lastUpdated' => '1178790125',
    'message' => 'Die aktuelle Ansicht des Kalenders. Entweder "Tag", "Woche" oder  "Monat".'
  },
  'previous day' => {
    'lastUpdated' => '1217146285',
    'message' => 'Vorheriger Tag'
  },
  'previous page' => {
    'lastUpdated' => '1217146312',
    'message' => 'Vorherige Seite'
  },
  'previous week' => {
    'lastUpdated' => '1217146335',
    'message' => 'Vorherige Woche'
  },
  'print' => {
    'lastUpdated' => '1192786234',
    'message' => 'Drucken'
  },
  'search results' => {
    'lastUpdated' => '1217146323',
    'message' => 'Suchergebnisse'
  },
  'searchButtonLabel' => {
    'lastUpdated' => '1178790130',
    'message' => 'Suche'
  },
  'sortEventsBy description' => {
    'lastUpdated' => '1201601599',
    'message' => 'Anzeigereihenfolge der täglichen Termine.'
  },
  'sortEventsBy label' => {
    'lastUpdated' => '1201601651',
    'message' => 'Anzeigereihenfolge tägliche Termine'
  },
  'sortEventsBy value sequencenumber' => {
    'lastUpdated' => '1201601673',
    'message' => 'Sortiere nach Folgenummer.'
  },
  'sortEventsBy value time' => {
    'lastUpdated' => '1201601697',
    'message' => 'Sortiere nach Startdatum / Enddatum.'
  },
  'start date' => {
    'lastUpdated' => '1217146495',
    'message' => 'Anfangsdatum'
  },
  'startDayAbbr' => {
    'lastUpdated' => '1178790158',
    'message' => 'Die Abkürzung f&uuml;r den Namen des Tages mit dem diese Woche beginnt.'
  },
  'startDayName' => {
    'lastUpdated' => '1178790174',
    'message' => 'Der Name des Tages mit dem diese Woche beginnt.'
  },
  'startDayOfMonth' => {
    'lastUpdated' => '1178790233',
    'message' => 'Der Tag des Monats in dem diese Woche startet; Zahl zwischen 1 und 31.'
  },
  'startMonth' => {
    'lastUpdated' => '1178790222',
    'message' => 'Die Nummer (1-12) des Monats in dem diese Woche beginnt.'
  },
  'startMonthAbbr' => {
    'lastUpdated' => '1178790255',
    'message' => 'Die Abkürzung des Namens des Monats in dem diese Woche beginnt.'
  },
  'startMonthName' => {
    'lastUpdated' => '1178790271',
    'message' => 'Der Name des Monats in dem diese Woche beginnt.'
  },
  'startYear' => {
    'lastUpdated' => '1178790286',
    'message' => 'Das Jahr in dem diese Woche beginnt.'
  },
  'subscribe' => {
    'lastUpdated' => '1217146456',
    'message' => 'Abonnieren'
  },
  'subscriberNotifyOffset description' => {
    'lastUpdated' => '1178790334',
    'message' => 'Anzahl Tage, bevor ein Subscriber informiert wird, dass ein Termin stattfinden wird.'
  },
  'subscriberNotifyOffset label' => {
    'lastUpdated' => '1178790367',
    'message' => 'Subscriber Benachrichtigung Offset'
  },
  'templateIdDay description' => {
    'lastUpdated' => '1178790387',
    'message' => 'Dieses Template zeigt den Kalender in der Tagesansicht.'
  },
  'templateIdDay label' => {
    'lastUpdated' => '1178790398',
    'message' => 'Tagesansicht Template'
  },
  'templateIdEvent description' => {
    'lastUpdated' => '1178790602',
    'message' => 'Das Template, das für die Anzeige von Details &uuml;ber einen Termin benutzt wird.'
  },
  'templateIdEvent label' => {
    'lastUpdated' => '1178793691',
    'message' => 'Termin Details Template'
  },
  'templateIdEventEdit description' => {
    'lastUpdated' => '1178793724',
    'message' => 'Das Template für die Bearbeitung von Terminen.'
  },
  'templateIdEventEdit label' => {
    'lastUpdated' => '1178793747',
    'message' => 'Termin Bearbeitung Template'
  },
  'templateIdMonth description' => {
    'lastUpdated' => '1178793781',
    'message' => 'Dieses Template zeigt den Kalender in der Monatsansicht.'
  },
  'templateIdMonth label' => {
    'lastUpdated' => '1178793810',
    'message' => 'Monatsansicht Template'
  },
  'templateIdPrintDay description' => {
    'lastUpdated' => '1178793847',
    'message' => 'Dieses Template ist für den Ausruck des Kalenders in der Tagesansicht.'
  },
  'templateIdPrintDay label' => {
    'lastUpdated' => '1178793863',
    'message' => 'Drucke Tag Template'
  },
  'templateIdPrintEvent description' => {
    'lastUpdated' => '1178793887',
    'message' => 'Dieses Template ist für den Ausdruck der Details eines Termins.'
  },
  'templateIdPrintEvent label' => {
    'lastUpdated' => '1178793901',
    'message' => 'Drucke Termin Details Template'
  },
  'templateIdPrintMonth description' => {
    'lastUpdated' => '1178793932',
    'message' => 'Dieses Template ist für den Ausdruck des Kalenders in der Monatsansicht.'
  },
  'templateIdPrintMonth label' => {
    'lastUpdated' => '1178793942',
    'message' => 'Drucke Monat Template'
  },
  'templateIdPrintWeek description' => {
    'lastUpdated' => '1178793967',
    'message' => 'Dieses Template ist für den Ausdruck des Kalenders in der Wochenansicht.'
  },
  'templateIdPrintWeek label' => {
    'lastUpdated' => '1178793980',
    'message' => 'Drucke Woche Template'
  },
  'templateIdSearch description' => {
    'lastUpdated' => '1178794001',
    'message' => 'Dieses Template zeigt den Kalender in der Suchansicht.'
  },
  'templateIdSearch label' => {
    'lastUpdated' => '1178794020',
    'message' => 'Suchansicht Template'
  },
  'templateIdWeek description' => {
    'lastUpdated' => '1178794038',
    'message' => 'Dieses Template zeigt den Kalender in der Wochenansicht.'
  },
  'templateIdWeek label' => {
    'lastUpdated' => '1178794047',
    'message' => 'Wochenansicht Template'
  },
  'urlAdd' => {
    'lastUpdated' => '1178794075',
    'message' => 'URL für das Hinzuf&uuml;gen eines Termins zum Kalender.'
  },
  'urlDay' => {
    'lastUpdated' => '1178794114',
    'message' => 'URL zur  Eintagesansicht des Kalenders.'
  },
  'urlIcal' => {
    'lastUpdated' => '1178794142',
    'message' => 'URL zum iCal Feed des Kalenders, startet in diesem Monat.'
  },
  'urlMonth' => {
    'lastUpdated' => '1178794157',
    'message' => 'URL zu der Monatsansicht des Kalenders.'
  },
  'urlPrint' => {
    'lastUpdated' => '1178794172',
    'message' => 'URL zur Druckansicht des Kalenders.'
  },
  'urlSearch' => {
    'lastUpdated' => '1178794194',
    'message' => 'URL zur Suchansicht des Kalenders.'
  },
  'urlWeek' => {
    'lastUpdated' => '1178794210',
    'message' => 'URL zur Wochenansicht des Kalenders.'
  },
  'view calendar body' => {
    'lastUpdated' => '1178794294',
    'message' => 'Der Kalender kann den ganzen Monat, eine Woche oder nur einen Tag anzeigen. Jede Ansicht hat seine eigenen, individuellen Template Variablen, sie teilen sich aber auch einen bestimmten Satz an Variablen. Diese werden im folgenden aufgelistet:'
  },
  'view calendar day body' => {
    'lastUpdated' => '1178794325',
    'message' => 'Dieses Template zeigt alle Termine an einem einzigen Tag in dem Kalender, sortiert nach der Stunde.'
  },
  'view calendar day title' => {
    'lastUpdated' => '1269421570',
    'message' => 'Kalenderansicht Tages-Template-Variablen'
  },
  'view calendar month body' => {
    'lastUpdated' => '1269421644',
    'message' => 'Dieses Template zeigt alle alle Kalendereinträge eines Monats an-'
  },
  'view calendar month title' => {
    'lastUpdated' => '1269421670',
    'message' => 'Kalenderansicht Monats-Template-Variablen '
  },
  'view calendar title' => {
    'lastUpdated' => '1269421582',
    'message' => 'Kalenderansicht Template Variablen'
  },
  'view calendar week body' => {
    'lastUpdated' => '1178794396',
    'message' => 'Dieses Template zeigt alle Termine in einer Woche des Kalenders, sortiert nach dem Tag.'
  },
  'view calendar week title' => {
    'lastUpdated' => '1269421604',
    'message' => 'Kalenderansicht Wochen-Template-Variablen'
  },
  'visitorCacheTimeout description' => {
    'lastUpdated' => '1178794449',
    'message' => 'Die Anzahl an Minuten, bevor der Cache des Besuchers (Visitor) erneuert wird.'
  },
  'visitorCacheTimeout label' => {
    'lastUpdated' => '1178794465',
    'message' => 'Besucher (Visitor) Cache Timeout'
  },
  'weeks' => {
    'lastUpdated' => '1269421717',
    'message' => 'Eine Schliefe, die Schleifen über die Einträge pro Tag enthält'
  },
  'workflow generateRecurringEvents' => {
    'lastUpdated' => '1178794479',
    'message' => 'Erzeuge wiederkehrende Termine'
  },
  'workflow generateRecurringEvents description' => {
    'lastUpdated' => '1178794534',
    'message' => 'Diese Aktivität erzeugt wiederkehrende Termine für Kalender. Sie verwaltet auch wiederkehrende Termine in der Zukunft.'
  },
  'workflow updateFeeds' => {
    'lastUpdated' => '1178794548',
    'message' => 'Erneuere Kalender Feeds'
  },
  'workflow updateFeeds description' => {
    'lastUpdated' => '1178794575',
    'message' => 'Diese Akitivität importiert Kalender Termine von Kalender Feeds'
  },
  'year' => {
    'lastUpdated' => '1178794593',
    'message' => 'Das Jahr in 4 Ziffern.'
  },
  'ymd' => {
    'lastUpdated' => '1178794639',
    'message' => 'Das Datum dieses Tages im yyyy-mm-dd Format; yyyy -> Jahr, mm -> Monat, dd -> Tag.'
  }
}
;

1;
